@@ -31,7 +31,7 @@ extern "C"
 {
 # endif
 
-# define GSASL_VERSION "0.2.0"
+# define GSASL_VERSION "0.2.1"
 
   /* RFC 2222: SASL mechanisms are named by strings, from 1 to 20
    * characters in length, consisting of upper-case letters, digits,
@@ -61,7 +61,6 @@ extern "C"
     GSASL_SASLPREP_ERROR = 29,
     GSASL_MECHANISM_PARSE_ERROR = 30,
     GSASL_AUTHENTICATION_ERROR = 31,
-    GSASL_CANNOT_GET_CTX = 32,
     GSASL_INTEGRITY_ERROR = 33,
     GSASL_NO_MORE_REALMS = 34,
     GSASL_NO_CLIENT_CODE = 35,
@@ -242,8 +241,10 @@ extern "C"
   /* Get the mechanism API. */
 # include <gsasl-mech.h>
 
+#ifndef GSASL_NO_OBSOLETE
   /* For compatibility with earlier versions. */
 # include <gsasl-compat.h>
+#endif
 
 # ifdef __cplusplus
 }
